
import numpy as np
from io import BytesIO
import langid
import wave

JETSON_SPEAKER = 'PCM2704C'
VOLUME_CONSTANTS= {
    'onnx':0.5,
    'bpu':0.1,
    'trt':0.5*(1/1.2),
}

def combine_audio_samples(audio_list, sample_rate_list):
    audio_data = b''
    sample_rate = None
    for audio, sr in zip(audio_list, sample_rate_list):
        if audio is not None:
            audio_data += audio
            sample_rate = sr
    return audio_data, sample_rate

def byte2np(byte, volume,volume_constant):
    samples = np.frombuffer(byte, dtype=np.int16)
    # Find the maximum absolute value of the samples
    max_sample = np.max(np.abs(samples))
    # Normalize the samples by dividing by the maximum absolute value 
    # and an adjusting constant
    normalized_samples = (samples / max_sample) * volume_constant * volume
    # Clip the normalized samples to the range of -1 to 1
    normalized_samples = np.clip(normalized_samples, -1.0, 1.0)
    return normalized_samples
    
def raw_wav2byte(obyte):
    bs = obyte.getvalue()
    # add the wav file header
    wav_file=bytes(b'RIFF')+ (len(bs)+38).to_bytes(4, byteorder='little')+b'WAVEfmt\x20\x12\x00\x00' \
                                                                b'\x00\x01\x00\x01\x00' \
                                                                b'\x22\x56\x00\x00\x44\xac\x00\x00' +\
        b'\x02\x00\x10\x00\x00\x00data' +(len(bs)).to_bytes(4, byteorder='little')+bs
    # changed to BytesIO
    wav_file=BytesIO(wav_file)
    return wavfile2byte(wav_file)

def wavfile2byte(path):
    with wave.open(path, 'rb') as wav:
        # Extract the audio data and the sample rate
        audio_data = wav.readframes(wav.getnframes())
        sample_rate = wav.getframerate()
    return audio_data ,sample_rate

def split_en_and_zh(text):
    '''
    input: text
    output: dict of {lang: text}
    eg: {'en': 'hello world', 'zh': '你好世界'}
    '''
    text_portion_ln_map = {}
    for i,sent in  enumerate(text.split()):
        ln = langid.classify(sent)[0]
        if ln not in text_portion_ln_map:
            text_portion_ln_map[ln] = []
        text_portion_ln_map[ln].append(sent)

    for ln in text_portion_ln_map:
        text_portion_ln_map[ln] = ' '.join(text_portion_ln_map[ln])

    return text_portion_ln_map