import os
from ament_index_python.packages import get_package_share_directory
from launch import LaunchDescription
from launch_ros.actions import Node, LifecycleNode
from launch.actions import EmitEvent, DeclareLaunchArgument
from launch_ros.events.lifecycle import ChangeState
from launch.events import matches_action
from lifecycle_msgs.msg import Transition
from launch.substitutions import LaunchConfiguration, PathJoinSubstitution


def generate_launch_description():
    config_file = LaunchConfiguration("config_file")
    config_file_launch_arg = DeclareLaunchArgument(
        "config_file",
        default_value="pc.yaml",
        description="Config file to load",
    )
    tts = LifecycleNode(
        package='tts',
        executable='tts_node',
        name='tts_node',
        parameters=[
            PathJoinSubstitution([
                get_package_share_directory("tts"), 
                "config", 
                config_file
        ])]
    )
    return LaunchDescription([
        config_file_launch_arg,
        tts,
        EmitEvent(event=ChangeState(
            lifecycle_node_matcher=matches_action(tts),
            transition_id=Transition.TRANSITION_CONFIGURE,
        )),
        EmitEvent(event=ChangeState(
            lifecycle_node_matcher=matches_action(tts),
            transition_id=Transition.TRANSITION_ACTIVATE,
        ))
    ])
